@@ -4,7 +4,7 @@
 
    Author: Ilan Schnell
 */
-#define BITARRAY_VERSION  "2.3.6"
+#define BITARRAY_VERSION  "2.3.7"
 
 #ifdef STDC_HEADERS
 #include <stddef.h>
@@ -61,9 +61,6 @@ typedef struct {
 /* the endianness string */
 #define ENDIAN_STR(endian)  ((endian) == ENDIAN_LITTLE ? "little" : "big")
 
-/* number of bits that can be stored in given bytes */
-#define BITS(bytes)  ((bytes) << 3)
-
 /* number of bytes necessary to store given bits */
 #define BYTES(bits)  (((bits) + 7) >> 3)
 
@@ -126,7 +123,7 @@ zeroed_last_byte(bitarrayobject *self)
     return mask_table[self->endian == ENDIAN_BIG][r] & self->ob_item[t];
 }
 
-/* Unless the buffer is readonly, zero out pad bits.
+/* Unless buffer is readonly, zero out pad bits.
    Always return the number of pad bits - leave self->nbits unchanged */
 static inline int
 setunused(bitarrayobject *self)
@@ -155,17 +152,20 @@ static const unsigned char bitcount_lookup[256] = {
 #undef B6
 };
 
-/* normalize index (which may be negative), such that 0 <= i <= n */
+/* normalize index (which may be negative), such that:
+    0 <= i <= length        (for step > 0)
+   -1 <= i <= length - 1    (for step < 0)                           */
 static inline void
-normalize_index(Py_ssize_t n, Py_ssize_t *i)
+normalize_index(Py_ssize_t length, Py_ssize_t step, Py_ssize_t *i)
 {
     if (*i < 0) {
-        *i += n;
+        *i += length;
         if (*i < 0)
-            *i = 0;
+            *i = (step < 0) ? -1 : 0;
+    }
+    else if (*i >= length) {
+        *i = (step < 0) ? length - 1 : length;
     }
-    if (*i > n)
-        *i = n;
 }
 
 /* Interpret a PyObject (usually PyLong or PyBool) as a bit, return 0 or 1.
